from .Options import Options
from .SetupInfo import DeviceInfo, DetectorInfo, LaserInfo, PositionerInfo, ScanInfo, SetupInfo
from .errors import *
from .managers import *
from .signaldesigners import SignalDesignerFactory
import sys

sys.modules['visa'] = 'pyvisa'